API docs for “spamfighter.core.counters.AverageCounter”

# Class s.c.c.AverageCounter(Counter):

Part of spamfighter.core.counters View Source View In Hierarchy

Known subclasses: spamfighter.core.counters.AverageServiceTimeCounter

Счетчик, измеряющий среднее значение величины.

Method | values | Получить значения счетчиков в виде массива значений.

Inherited from Counter:

Method | increment | Увеличить значение счетчика на указанное значение.
Method | __str__ | Представить текущее состояние счетчика в понятном человеку виде.
Method | format | Строка формата для вывода значения счетчика.

def values(self): (source)
overrides spamfighter.core.counters.Counter.values
Получить значения счетчиков в виде массива значений.